;; Generated package description from xah-fly-keys.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "xah-fly-keys" "28.11.20260215192642" "ergonomic modal keybinding minor mode." '((emacs "28.3")) :commit "10316e7bd865e5ba23291d7fd939649201a214a5" :maintainer '("Xah Lee" . "xah@xahlee.org") :keywords '("convenience" "vi" "vim" "ergoemacs" "keybinding") :url "http://xahlee.info/emacs/misc/xah-fly-keys.html")
